@@ -1246,8 +1246,8 @@ char *trimxmlchars(char *str) {
       }
     }
     if(len < 1) break;
-    if(c == 0x0A || c == 0x0D || (c >= 0x20 && c <= 0xD7FF) ||
-        false) {
+    if(c == 0x0A || c == 0x0D || (c >= 0x20 && c <= 0xD7FF) || (c >= 0xE000 && c <= 0xFFFD) ||
+       (c >= 0x10000 && c <= 0x10FFFF)) {
       while (len-- > 0) {
         *(wp++) = *(rp++);
       }
