@@ -48,6 +48,7 @@ const char *g_upload;                    // path of the upload directory
 const char *g_uploadpub;                 // public path of the upload directory
 const char *g_scrext;                    // path of the script extension file
 int64_t g_recvmax;                       // maximum size of received data
+const char *g_mimerule;                  // mime dicision rule
 const char *g_title;                     // site title
 int g_searchnum;                         // number of articles in a search page
 int g_listnum;                           // number of articles in a list page
@@ -173,6 +174,7 @@ static int realmain(int argc, char **argv){
         g_scrextproc = tcmpoolpush(g_mpool, scrextnew(), scrextdel);
       const char *rp = tctmplconf(g_tmpl, "recvmax");
       g_recvmax = rp ? tcatoix(rp) : INT_MAX;
+      g_mimerule = tctmplconf(g_tmpl, "mimerule");
       g_title = tctmplconf(g_tmpl, "title");
       if(!g_title) g_title = "Tokyo Promenade";
       rp = tctmplconf(g_tmpl, "searchnum");
@@ -411,8 +413,14 @@ static void dosession(TCMPOOL *mpool){
     p_userlang = lang;
   }
   if(*p_format == '\0'){
-    rp = getenv("HTTP_ACCEPT");
-    if(rp && strstr(rp, "application/xhtml+xml")) p_format = "xhtml";
+    if(!strcmp(g_mimerule, "xhtml")) {
+      p_format = "xhtml";
+    } else if(!strcmp(g_mimerule, "html")) {
+      p_format = "html";
+    } else {
+      rp = getenv("HTTP_ACCEPT");
+      if(rp && strstr(rp, "application/xhtml+xml")) p_format = "xhtml";
+    }
   }
   // perform authentication
   bool auth = true;
@@ -1371,7 +1379,7 @@ static void dosession(TCMPOOL *mpool){
     mtype = "application/xml";
   }
   tcmapput2(vars, "mimetype", mtype);
-  const char *tmplstr = tcmpoolpushptr(mpool, tctmpldump(g_tmpl, vars));
+  const char *tmplstr = trimxmlchars(tcmpoolpushptr(mpool, tctmpldump(g_tmpl, vars)));
   while(*tmplstr > '\0' && *tmplstr <= ' '){
     tmplstr++;
   }
